@@ -1,6 +1,6 @@
 import random
 from pyage.core.operator import Operator
-from pyage.solutions.evolution.genotype import PointGenotype
+from pyage.solutions.evolution.genotype import PointGenotype, FloatGenotype
 
 class AbstractMutation(Operator):
     def __init__(self, type, probability):
@@ -24,3 +24,13 @@ class UniformPointMutation(AbstractMutation):
         genotype.y = genotype.y + random.uniform(-self.radius, self.radius)
 
 
+class UniformFloatMutation(AbstractMutation):
+    def __init__(self, probability=0.1, radius=100.5):
+        super(UniformFloatMutation, self).__init__(FloatGenotype, probability)
+        self.radius = radius
+
+
+    def mutate(self, genotype):
+        index = random.randint(0, len(genotype.genes) - 1)
+        genotype.genes[index] += random.uniform(-self.radius, self.radius)
+
